#!/usr/bin/python

import requests
from warnings import warn


def uploadfile(filePath, name="", random_name=False):
    """Return the file url if the file at the given path
    was successfully uploaded. Returns an empty string otherwise.

    :param string filePath: File path relative to the script.
    :param string name: Custom name you wish to give to the file. Don't forget the extension!
    :param bool random_name: Whether you wish the file to have a random name assigned to it.
    :rtype: string

    """
    url = "https://uguu.se/api.php?d=upload-tool"

    if random_name & (name == ""):
        randomn = "a"  # so far uguu just needs a string that isn't empty.
    elif random_name & (name != ""):
        warn("Only one of the optional arguments should be used. In this case, the custom name will be overwritten.")
        randomn = "a"
    else:
        randomn = ""

    payload = {"name": name, "randomname": randomn}

    with open(filePath, "rb") as file:
        response = requests.post(url, files={"file": file}, data=payload)

    if response.status_code != requests.codes.ok:
        raise response.raise_for_status()

    if response.content == "You did not send a file, try again.":  # I don't think this is actually possible.
        return ""
    else:
        return response.content
